# A GH81-type β-glucan-binding protein enhances colonization by mutualistic fungi in barley

## Summary

Cell walls are important interfaces of plant-fungal interactions, acting as robust physical and chemical barriers against invaders. Upon fungal colonization, plants deposit phenolics and callose at the sites of fungal penetration to prevent further fungal progression. Alterations in the composition of plant cell walls significantly impact host susceptibility. Furthermore, plants and fungi secrete glycan hydrolases acting on each other’s cell walls. These enzymes release various sugar oligomers into the apoplast, some of which activate host immunity via surface receptors. Recent characterization of cell walls from plant-colonizing fungi has emphasized the abundance of β-glucans in different cell wall layers, which makes them suitable targets for recognition. To characterize host components involved in immunity against fungi, we performed a protein pull-down with the biotinylated β-glucan laminarin. Thereby, we identified a plant glycoside hydrolase family 81-type glucan-binding protein (GBP) as a β-glucan interactor. Mutation of *GBP1* and its only paralog, *GBP2*, in barley led to decreased colonization by the beneficial root endophytes *Serendipita indica* and *S. vermifera*, as well as the arbuscular mycorrhizal fungus *Rhizophagus irregularis*. The reduction of colonization was accompanied by enhanced responses at the host cell wall, including an extension of callose-containing cell wall appositions. Moreover, *GBP* mutation in barley also reduced fungal biomass in roots by the hemibiotrophic pathogen *Bipolaris sorokiniana* and inhibited the penetration success of the obligate biotrophic leaf pathogen *Blumeria hordei*. These results indicate that GBP1 is involved in the establishment of symbiotic associations with beneficial fungi—a role that has potentially been appropriated by barley-adapted pathogens.

<img src=./_publication/1-s2.0-S0960982223014495-fx1_lrg.jpg width=50%>

## Original publication
Wanke, A., van Boerdonk, S., Mahdi, L. K., Wawra, S., Neidert, M., Chandrasekar, B., Saake, P., Saur, I. M. L., Derbyshire, P., Holton, N., Menke, F. L. H., Brands, M., Pauly, M., Acosta, I. F., Zipfel, C., & Zuccaro, A. (2023). A GH81-type β-glucan-binding protein enhances colonization by mutualistic fungi in barley. Current biology : CB, 33(23), 5071–5084.e7. https://doi.org/10.1016/j.cub.2023.10.048

## License
Copyright © 2023 The Authors. Published by Elsevier Inc. All rights reserved.

## Data availability

Lead Contact

Further information and requests for resources, reagents, datasets, and protocols should be directed to and will be fulfilled by the lead contact, Alga Zuccaro (azuccaro@uni-koeln.de).

Materials Availability

Plasmids and barley lines generated in this study are available upon request and will be provided by the lead contact, Alga Zuccaro (azuccaro@uni-koeln.de).

Data and Code Availability

Proteomic data has been deposited at the ProteomeXchange Consortium via PRIDE partner repository (Perez-Riverol et al., 2019) and are publicly available as of the date of publication. Accession numbers are listed in the key resources table.

This paper does not report original code.

Any additional information required to reanalyze the data reported in this paper is available from the lead contact upon request.

## ARC structure

``` mermaid
flowchart

subgraph CarbohydrateSubstratesForImmunityAndEnzymaticDigestionAssays
end

subgraph HordeumVulgare
  ROS_burst_assay_preparation
  germination
  growth_chamber
end

subgraph NicotianaBenthamiana
  greenhouse_conditions
end

subgraph HeterologousProteinProductionAndPurification
  Agrobacterium_growth
  Nicotiana_infiltration
  ground_material
  incubation
  purification
end

subgraph PlasmidConstructionForHeterologousProteinProduction
  amplification
  cloning
  site-directed_mutagenesis_PCR
  purification_and_E.coli_transfo
  Agrobacterium_transformation
end

subgraph ProteinPull-down
  biothinylation_of_laminarin
  extraction
  incubation
  pull-down
  SDS-PAGE
end

subgraph OxidativeBurstAssay
  preparation_of_plant_material
  ROS_burst_assay
end

subgraph MALDI-TOFAnalysis
  MALDI-TOF
end

subgraph EnzymaticCarbohydrateDigestionAndTLC
  EnzymaticCarbohydrateDigestion
  TLC
end

subgraph StainingForConfocalMicroscopy
  staining
end

subgraph CRISPRCas9-basedMutagenesis
  expression_cassettes
  plasmid_generation
  CRISPR_Cas9_mutagenesis
end

subgraph MultipleSequenceAlignment
  alignment
end

subgraph MS-MSAnalysisOfThePull-downProteins
  MS-MS_analysis
end

subgraph FungalMaterialGrowthConditionsAndBarleyColonizationAssays
  R.irregularis
  R.irregularis_staining
  Si_Sv_Bs
  B.hordei
  B.hordei_staining
end

subgraph QuantificationAndStatisticalAnalyses
end

subgraph qRT-PCR
  RT-PCR
end


Wanke-2023 --> CarbohydrateSubstratesForImmunityAndEnzymaticDigestionAssays
Wanke-2023 --> HordeumVulgare
Wanke-2023 --> NicotianaBenthamiana

ROS_burst_assay_preparation --3--> germination
germination --3--> growth_chamber
growth_chamber --3--> preparation_of_plant_material
growth_chamber --1--> R.irregularis
growth_chamber --1--> Si_Sv_Bs
growth_chamber --1--> B.hordei
greenhouse_conditions --1--> preparation_of_plant_material
Agrobacterium_growth --3--> Nicotiana_infiltration
Nicotiana_infiltration --1--> ground_material
ground_material --1--> incubation
incubation --1--> purification
purification --2--> EnzymaticCarbohydrateDigestion
amplification --1--> cloning
cloning --1--> site-directed_mutagenesis_PCR
cloning --1--> Agrobacterium_transformation
site-directed_mutagenesis_PCR --1--> purification_and_E.coli_transfo
purification_and_E.coli_transfo --1--> Agrobacterium_transformation
Agrobacterium_transformation --2--> Agrobacterium_growth
biothinylation_of_laminarin --1--> extraction
extraction --1--> incubation
incubation --6--> pull-down
pull-down --6--> SDS-PAGE
SDS-PAGE --5--> MS-MS_analysis
preparation_of_plant_material --6--> ROS_burst_assay
EnzymaticCarbohydrateDigestion --28--> MALDI-TOF
EnzymaticCarbohydrateDigestion --28--> TLC
expression_cassettes --3--> plasmid_generation
plasmid_generation --1--> CRISPR_Cas9_mutagenesis
CRISPR_Cas9_mutagenesis --2--> ROS_burst_assay_preparation
R.irregularis --3--> R.irregularis_staining
Si_Sv_Bs --3--> staining
Si_Sv_Bs --9--> RT-PCR
B.hordei --3--> B.hordei_staining
```

